@@ -3,7 +3,7 @@ ldapobject.py - wraps class _ldap.LDAPObject
 
 See http://www.python-ldap.org/ for details.
 
-\$Id: ldapobject.py,v 1.133 2012/06/02 10:23:15 stroeder Exp $
+\$Id: ldapobject.py,v 1.135 2013/06/25 17:36:03 stroeder Exp $
 
 Compability:
 - Tested with Python 2.0+ but should work with Python 1.5.x
@@ -753,7 +753,10 @@ class ReconnectLDAPObject(SimpleLDAPObject):
   def _apply_last_bind(self):
     if self._last_bind!=None:
       func,args,kwargs = self._last_bind
-      func(*args,**kwargs)
+      func(self,*args,**kwargs)
+    else:
+      # Send explicit anon simple bind request to provoke ldap.SERVER_DOWN in method reconnect()
+      SimpleLDAPObject.simple_bind_s(self,'','')
 
   def _restore_options(self):
     """Restore all recorded options"""
@@ -782,9 +785,7 @@ class ReconnectLDAPObject(SimpleLDAPObject):
           self.start_tls_s()
         # Repeat last simple or SASL bind
         self._apply_last_bind()
-      except ldap.SERVER_DOWN,e:
-        SimpleLDAPObject.unbind_s(self)
-        del self._l
+      except (ldap.SERVER_DOWN,ldap.TIMEOUT),e:
         if __debug__ and self._trace_level>=1:
           self._trace_file.write('*** %d. reconnect to %s failed\n' % (
             self._retry_max-reconnect_counter+1,uri
@@ -795,6 +796,8 @@ class ReconnectLDAPObject(SimpleLDAPObject):
         if __debug__ and self._trace_level>=1:
           self._trace_file.write('=> delay %s...\n' % (self._retry_delay))
         time.sleep(self._retry_delay)
+        SimpleLDAPObject.unbind_s(self)
+        del self._l
       else:
         if __debug__ and self._trace_level>=1:
           self._trace_file.write('*** %d. reconnect to %s successful, last operation will be repeated\n' % (
@@ -829,7 +832,7 @@ class ReconnectLDAPObject(SimpleLDAPObject):
 
   def simple_bind_s(self,*args,**kwargs):
     res = self._apply_method_s(SimpleLDAPObject.simple_bind_s,*args,**kwargs)
-    self._last_bind = (self.simple_bind_s,args,kwargs)
+    self._last_bind = (SimpleLDAPObject.simple_bind_s,args,kwargs)
     return res
 
   def start_tls_s(self,*args,**kwargs):
@@ -842,7 +845,7 @@ class ReconnectLDAPObject(SimpleLDAPObject):
     sasl_interactive_bind_s(who, auth) -> None
     """
     res = self._apply_method_s(SimpleLDAPObject.sasl_interactive_bind_s,*args,**kwargs)
-    self._last_bind = (self.sasl_interactive_bind_s,args,kwargs)
+    self._last_bind = (SimpleLDAPObject.sasl_interactive_bind_s,args,kwargs)
     return res
 
   def add_ext_s(self,*args,**kwargs):
